magneticalc.QtWidgets2.QHBoxLayout2.QHBoxLayout2

# ``magneticalc`.`QtWidgets2`.`QHBoxLayout2`.`QHBoxLayout2``

class documentation

`class QHBoxLayout2(QHBoxLayout):`

Constructor: `QHBoxLayout2(*elements)`

View In Hierarchy

QHBoxLayout2 class.

Method | `__init__` | Initializes a horizontal layout with multiple elements at once.

def __init__(self, *elements: `QWidget | QLayout`):

Initializes a horizontal layout with multiple elements at once.

Parameters
*elements: `QWidget | QLayout` | Arbitrary arguments of QWidget and QLayout